@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import torch
 import torch.nn as nn
 from mmcv.cnn import ConvModule
@@ -17,25 +18,32 @@ class FCNHead(BaseDecodeHead):
         kernel_size (int): The kernel size for convs in the head. Default: 3.
         concat_input (bool): Whether concat the input and output of convs
             before classification layer.
+        dilation (int): The dilation rate for convs in the head. Default: 1.
     """
 
     def __init__(self,
                  num_convs=2,
                  kernel_size=3,
                  concat_input=True,
+                 dilation=1,
                  **kwargs):
-        assert num_convs > 0
+        assert num_convs >= 0 and dilation > 0 and isinstance(dilation, int)
         self.num_convs = num_convs
         self.concat_input = concat_input
         self.kernel_size = kernel_size
         super(FCNHead, self).__init__(**kwargs)
+        if num_convs == 0:
+            assert self.in_channels == self.channels
+
+        conv_padding = (kernel_size // 2) * dilation
         convs = []
         convs.append(
             ConvModule(
                 self.in_channels,
                 self.channels,
                 kernel_size=kernel_size,
-                padding=kernel_size // 2,
+                padding=conv_padding,
+                dilation=dilation,
                 conv_cfg=self.conv_cfg,
                 norm_cfg=self.norm_cfg,
                 act_cfg=self.act_cfg))
@@ -45,11 +53,15 @@ class FCNHead(BaseDecodeHead):
                     self.channels,
                     self.channels,
                     kernel_size=kernel_size,
-                    padding=kernel_size // 2,
+                    padding=conv_padding,
+                    dilation=dilation,
                     conv_cfg=self.conv_cfg,
                     norm_cfg=self.norm_cfg,
                     act_cfg=self.act_cfg))
-        self.convs = nn.Sequential(*convs)
+        if num_convs == 0:
+            self.convs = nn.Identity()
+        else:
+            self.convs = nn.Sequential(*convs)
         if self.concat_input:
             self.conv_cat = ConvModule(
                 self.in_channels + self.channels,
