@@ -1,9 +1,10 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
 
 from ..builder import LOSSES
-from .utils import weight_reduce_loss
+from .utils import get_class_weight, weight_reduce_loss
 
 
 def cross_entropy(pred,
@@ -146,8 +147,8 @@ class CrossEntropyLoss(nn.Module):
             Defaults to False.
         reduction (str, optional): . Defaults to 'mean'.
             Options are "none", "mean" and "sum".
-        class_weight (list[float], optional): Weight of each class.
-            Defaults to None.
+        class_weight (list[float] | str, optional): Weight of each class. If in
+            str format, read them from a file. Defaults to None.
         loss_weight (float, optional): Weight of the loss. Defaults to 1.0.
     """
 
@@ -163,7 +164,7 @@ class CrossEntropyLoss(nn.Module):
         self.use_mask = use_mask
         self.reduction = reduction
         self.loss_weight = loss_weight
-        self.class_weight = class_weight
+        self.class_weight = get_class_weight(class_weight)
 
         if self.use_sigmoid:
             self.cls_criterion = binary_cross_entropy
